@@ -1,34 +1,32 @@
-# -*- coding: utf-8 -*-
 from five.localsitemanager import make_objectmanager_site
 from OFS.Folder import Folder
 from plone.app.workflow.exportimport import export_sharing
 from plone.app.workflow.exportimport import import_sharing
-from plone.app.workflow.exportimport import SharingXMLAdapter
 from plone.app.workflow.exportimport import PersistentSharingPageRole
+from plone.app.workflow.exportimport import SharingXMLAdapter
 from plone.app.workflow.interfaces import ISharingPageRole
 from plone.testing.zca import UNIT_TESTING
-from Products.GenericSetup.tests.common import DummyImportContext
 from Products.GenericSetup.tests.common import DummyExportContext
+from Products.GenericSetup.tests.common import DummyImportContext
 from zope.component import getSiteManager
 from zope.component import getUtilitiesFor
 from zope.component import provideAdapter
 from zope.component import provideUtility
+from zope.component.hooks import clearSite
+from zope.component.hooks import setHooks
+from zope.component.hooks import setSite
 from zope.interface import Interface
-from zope.site.hooks import clearSite
-from zope.site.hooks import setHooks
-from zope.site.hooks import setSite
 
 import unittest
 
 
 class ExportImportTest(unittest.TestCase):
-
     layer = UNIT_TESTING
 
     def setUp(self):
-        provideAdapter(SharingXMLAdapter, name='plone.app.workflow.sharing')
+        provideAdapter(SharingXMLAdapter, name="plone.app.workflow.sharing")
 
-        site = Folder('plone')
+        site = Folder("plone")
         make_objectmanager_site(site)
         setHooks()
         setSite(site)
@@ -45,19 +43,16 @@ class ExportImportTest(unittest.TestCase):
 
 
 class TestImport(ExportImportTest):
-
     def test_empty_import_no_purge(self):
-
         xml = "<sharing />"
         context = DummyImportContext(self.site, purge=False)
-        context._files = {'sharing.xml': xml}
+        context._files = {"sharing.xml": xml}
 
         import_sharing(context)
 
         self.assertEqual(0, len(self.roles()))
 
     def test_import_single_no_purge(self):
-
         xml = """\
 <sharing>
     <role id='CopyEditor'
@@ -67,19 +62,18 @@ class TestImport(ExportImportTest):
 </sharing>
 """
         context = DummyImportContext(self.site, purge=False)
-        context._files = {'sharing.xml': xml}
+        context._files = {"sharing.xml": xml}
 
         import_sharing(context)
         roles = self.roles()
 
         self.assertEqual(1, len(roles))
 
-        self.assertEqual('Can copyedit', roles['CopyEditor'].title)
-        self.assertEqual('Delegate edit copy', roles['CopyEditor'].required_permission)
-        self.assertEqual(Interface, roles['CopyEditor'].required_interface)
+        self.assertEqual("Can copyedit", roles["CopyEditor"].title)
+        self.assertEqual("Delegate edit copy", roles["CopyEditor"].required_permission)
+        self.assertEqual(Interface, roles["CopyEditor"].required_interface)
 
     def test_import_multiple_no_purge(self):
-
         xml = """\
 <sharing>
     <role id='CopyEditor'
@@ -91,20 +85,19 @@ class TestImport(ExportImportTest):
 </sharing>
 """
         context = DummyImportContext(self.site, purge=False)
-        context._files = {'sharing.xml': xml}
+        context._files = {"sharing.xml": xml}
 
         import_sharing(context)
         roles = self.roles()
 
         self.assertEqual(2, len(roles))
-        self.assertEqual('Can copyedit', roles['CopyEditor'].title)
-        self.assertEqual('Delegate edit copy', roles['CopyEditor'].required_permission)
-        self.assertEqual(Interface, roles['CopyEditor'].required_interface)
-        self.assertEqual('Can control', roles['Controller'].title)
-        self.assertEqual(None, roles['Controller'].required_permission)
+        self.assertEqual("Can copyedit", roles["CopyEditor"].title)
+        self.assertEqual("Delegate edit copy", roles["CopyEditor"].required_permission)
+        self.assertEqual(Interface, roles["CopyEditor"].required_interface)
+        self.assertEqual("Can control", roles["Controller"].title)
+        self.assertEqual(None, roles["Controller"].required_permission)
 
     def test_import_multiple_times_no_purge(self):
-
         xml = """\
 <sharing>
     <role id='CopyEditor'
@@ -114,15 +107,15 @@ class TestImport(ExportImportTest):
 </sharing>
 """
         context = DummyImportContext(self.site, purge=False)
-        context._files = {'sharing.xml': xml}
+        context._files = {"sharing.xml": xml}
 
         import_sharing(context)
         roles = self.roles()
 
         self.assertEqual(1, len(roles))
-        self.assertEqual('Can copyedit', roles['CopyEditor'].title)
-        self.assertEqual('Delegate edit copy', roles['CopyEditor'].required_permission)
-        self.assertEqual(Interface, roles['CopyEditor'].required_interface)
+        self.assertEqual("Can copyedit", roles["CopyEditor"].title)
+        self.assertEqual("Delegate edit copy", roles["CopyEditor"].required_permission)
+        self.assertEqual(Interface, roles["CopyEditor"].required_interface)
 
         xml = """\
 <sharing>
@@ -131,20 +124,19 @@ class TestImport(ExportImportTest):
 </sharing>
 """
         context = DummyImportContext(self.site, purge=False)
-        context._files = {'sharing.xml': xml}
+        context._files = {"sharing.xml": xml}
 
         import_sharing(context)
         roles = self.roles()
 
         self.assertEqual(2, len(roles))
-        self.assertEqual('Can copyedit', roles['CopyEditor'].title)
-        self.assertEqual('Delegate edit copy', roles['CopyEditor'].required_permission)
-        self.assertEqual(Interface, roles['CopyEditor'].required_interface)
-        self.assertEqual('Can control', roles['Controller'].title)
-        self.assertEqual(None, roles['Controller'].required_permission)
+        self.assertEqual("Can copyedit", roles["CopyEditor"].title)
+        self.assertEqual("Delegate edit copy", roles["CopyEditor"].required_permission)
+        self.assertEqual(Interface, roles["CopyEditor"].required_interface)
+        self.assertEqual("Can control", roles["Controller"].title)
+        self.assertEqual(None, roles["Controller"].required_permission)
 
     def test_import_multiples_times_purge(self):
-
         xml = """\
 <sharing>
     <role id='CopyEditor'
@@ -154,15 +146,15 @@ class TestImport(ExportImportTest):
 </sharing>
 """
         context = DummyImportContext(self.site, purge=False)
-        context._files = {'sharing.xml': xml}
+        context._files = {"sharing.xml": xml}
 
         import_sharing(context)
         roles = self.roles()
 
         self.assertEqual(1, len(roles))
-        self.assertEqual('Can copyedit', roles['CopyEditor'].title)
-        self.assertEqual('Delegate edit copy', roles['CopyEditor'].required_permission)
-        self.assertEqual(Interface, roles['CopyEditor'].required_interface)
+        self.assertEqual("Can copyedit", roles["CopyEditor"].title)
+        self.assertEqual("Delegate edit copy", roles["CopyEditor"].required_permission)
+        self.assertEqual(Interface, roles["CopyEditor"].required_interface)
 
         xml = """\
 <sharing>
@@ -171,17 +163,16 @@ class TestImport(ExportImportTest):
 </sharing>
 """
         context = DummyImportContext(self.site, purge=True)
-        context._files = {'sharing.xml': xml}
+        context._files = {"sharing.xml": xml}
 
         import_sharing(context)
         roles = self.roles()
 
         self.assertEqual(1, len(roles))
-        self.assertEqual('Can control', roles['Controller'].title)
-        self.assertEqual(None, roles['Controller'].required_permission)
+        self.assertEqual("Can control", roles["Controller"].title)
+        self.assertEqual(None, roles["Controller"].required_permission)
 
     def test_import_multiples_times_no_purge_overwrite(self):
-
         xml = """\
 <sharing>
     <role id='CopyEditor'
@@ -191,15 +182,15 @@ class TestImport(ExportImportTest):
 </sharing>
 """
         context = DummyImportContext(self.site, purge=False)
-        context._files = {'sharing.xml': xml}
+        context._files = {"sharing.xml": xml}
 
         import_sharing(context)
         roles = self.roles()
 
         self.assertEqual(1, len(roles))
-        self.assertEqual('Can copyedit', roles['CopyEditor'].title)
-        self.assertEqual('Delegate edit copy', roles['CopyEditor'].required_permission)
-        self.assertEqual(Interface, roles['CopyEditor'].required_interface)
+        self.assertEqual("Can copyedit", roles["CopyEditor"].title)
+        self.assertEqual("Delegate edit copy", roles["CopyEditor"].required_permission)
+        self.assertEqual(Interface, roles["CopyEditor"].required_interface)
 
         xml = """\
 <sharing>
@@ -209,19 +200,24 @@ class TestImport(ExportImportTest):
 </sharing>
 """
         context = DummyImportContext(self.site, purge=False)
-        context._files = {'sharing.xml': xml}
+        context._files = {"sharing.xml": xml}
 
         import_sharing(context)
         roles = self.roles()
 
         self.assertEqual(1, len(roles))
-        self.assertEqual('Can edit copy', roles['CopyEditor'].title)
-        self.assertEqual('Delegate: CopyEditor', roles['CopyEditor'].required_permission)
-        self.assertEqual(None, roles['CopyEditor'].required_interface)
+        self.assertEqual("Can edit copy", roles["CopyEditor"].title)
+        self.assertEqual(
+            "Delegate: CopyEditor", roles["CopyEditor"].required_permission
+        )
+        self.assertEqual(None, roles["CopyEditor"].required_interface)
 
     def test_import_override_global(self):
-
-        provideUtility(PersistentSharingPageRole("Do stuff", "A permission"), ISharingPageRole, name="DoerOfStuff")
+        provideUtility(
+            PersistentSharingPageRole("Do stuff", "A permission"),
+            ISharingPageRole,
+            name="DoerOfStuff",
+        )
 
         xml = """\
 <sharing>
@@ -234,20 +230,21 @@ class TestImport(ExportImportTest):
 </sharing>
 """
         context = DummyImportContext(self.site, purge=False)
-        context._files = {'sharing.xml': xml}
+        context._files = {"sharing.xml": xml}
 
         import_sharing(context)
         roles = self.roles()
 
         self.assertEqual(2, len(roles))
-        self.assertEqual('Can copyedit', roles['CopyEditor'].title)
-        self.assertEqual('Delegate edit copy', roles['CopyEditor'].required_permission)
-        self.assertEqual(None, roles['CopyEditor'].required_interface)
-        self.assertEqual('Can do stuff', roles['DoerOfStuff'].title)
-        self.assertEqual('Delegate doing stuff', roles['DoerOfStuff'].required_permission)
+        self.assertEqual("Can copyedit", roles["CopyEditor"].title)
+        self.assertEqual("Delegate edit copy", roles["CopyEditor"].required_permission)
+        self.assertEqual(None, roles["CopyEditor"].required_interface)
+        self.assertEqual("Can do stuff", roles["DoerOfStuff"].title)
+        self.assertEqual(
+            "Delegate doing stuff", roles["DoerOfStuff"].required_permission
+        )
 
     def test_remove_one(self):
-
         xml = """\
 <sharing>
     <role id='CopyEditor'
@@ -256,13 +253,13 @@ class TestImport(ExportImportTest):
 </sharing>
 """
         context = DummyImportContext(self.sm, purge=False)
-        context._files = {'sharing.xml': xml}
+        context._files = {"sharing.xml": xml}
 
         import_sharing(context)
         roles = self.roles()
 
         self.assertEqual(1, len(roles))
-        self.assertEqual('Can copyedit', roles['CopyEditor'].title)
+        self.assertEqual("Can copyedit", roles["CopyEditor"].title)
 
         xml = """\
 <sharing>
@@ -271,7 +268,7 @@ class TestImport(ExportImportTest):
 </sharing>
 """
         context = DummyImportContext(self.sm, purge=False)
-        context._files = {'sharing.xml': xml}
+        context._files = {"sharing.xml": xml}
 
         import_sharing(context)
         roles = self.roles()
@@ -290,7 +287,7 @@ class TestImport(ExportImportTest):
 </sharing>
 """
         context = DummyImportContext(self.sm, purge=False)
-        context._files = {'sharing.xml': xml}
+        context._files = {"sharing.xml": xml}
         import_sharing(context)
 
         xml = """\
@@ -305,20 +302,18 @@ class TestImport(ExportImportTest):
 </sharing>
 """
         context = DummyImportContext(self.sm, purge=False)
-        context._files = {'sharing.xml': xml}
+        context._files = {"sharing.xml": xml}
 
         import_sharing(context)
         roles = self.roles()
 
         self.assertEqual(2, len(roles))
-        self.assertEqual('Can do stuff', roles['DoerOfStuff'].title)
-        self.assertEqual('Can hack', roles['Hacker'].title)
+        self.assertEqual("Can do stuff", roles["DoerOfStuff"].title)
+        self.assertEqual("Can hack", roles["Hacker"].title)
 
 
 class TestExport(ExportImportTest):
-
     def test_export_empty(self):
-
         xml = b"""\
 <?xml version="1.0" encoding="utf-8"?>
 <sharing/>
@@ -326,17 +321,25 @@ class TestExport(ExportImportTest):
         context = DummyExportContext(self.site)
         export_sharing(context)
 
-        self.assertEqual(u'sharing.xml', context._wrote[0][0])
+        self.assertEqual("sharing.xml", context._wrote[0][0])
         self.assertEqual(xml, context._wrote[0][1])
 
     def test_export_multiple(self):
         sm = self.site.getSiteManager()
 
         # Will not be exported, as it's global
-        provideUtility(PersistentSharingPageRole("Do stuff", "A permission"), ISharingPageRole, name="DoerOfStuff")
+        provideUtility(
+            PersistentSharingPageRole("Do stuff", "A permission"),
+            ISharingPageRole,
+            name="DoerOfStuff",
+        )
 
         # Will not be exported, as it wasn't imported with this handler
-        sm.registerUtility(PersistentSharingPageRole("Do other Stuff"), ISharingPageRole, "DoerOfOtherStuff")
+        sm.registerUtility(
+            PersistentSharingPageRole("Do other Stuff"),
+            ISharingPageRole,
+            "DoerOfOtherStuff",
+        )
 
         import_xml = b"""\
 <sharing>
@@ -356,13 +359,13 @@ class TestExport(ExportImportTest):
 """
 
         import_context = DummyImportContext(self.site, purge=False)
-        import_context._files = {'sharing.xml': import_xml}
+        import_context._files = {"sharing.xml": import_xml}
 
         import_sharing(import_context)
 
         export_context = DummyExportContext(self.site)
         export_sharing(export_context)
 
-        self.assertEqual('sharing.xml', export_context._wrote[0][0])
+        self.assertEqual("sharing.xml", export_context._wrote[0][0])
 
         self.assertEqual(export_xml, export_context._wrote[0][1])
